@@ -200,11 +200,11 @@ if (! window._OQAjaxQueryLoaded)
     var $tr = $(this).closest('tr');
     var id = $tr.find('[data-id]').attr('data-id');
     var $f = $('.OQform');
+    var dat = buildParamMap($f);
+    dat.module = 'InteractiveQuery2Tools';
+    dat.OQdeleteSavedSearch = id;
     $.ajax({ url: $f[0].action, type: 'POST', dataType: 'json',
-      data: {
-        OQdeleteSavedSearch: id,
-        module: 'InteractiveQuery2Tools'
-      },
+      data: dat,
       complete: function(jqXHR) {
         if (/report\ deleted/.test(jqXHR.responseText)) {
           OQnotify("report deleted"); 
@@ -217,29 +217,85 @@ if (! window._OQAjaxQueryLoaded)
     return false;
   });
 
+  var parseHour = function(h) {
+    var rv = 0;
+    if (/(\d+)/.test(h)) rv = parseInt(RegExp.$1,10);
+    if (/AM/i.test(h) && rv == 12) rv = 0;
+    else if (/PM/i.test(h) && rv < 12) rv+=12;
+    if (rv >= 24) rv = 23;
+    return rv;
+  };
   $(document).delegate('.OQSaveReportBut', 'click', function(e) {
     var $f = $('.OQform');
     var dat = buildParamMap($f);
     dat.module = 'InteractiveQuery2Tools';
-    var $inp = $(this).parent().find('input');
-    dat.OQsaveSearchTitle = $.trim($inp.val());
+    dat.OQsaveSearchTitle = $("#OQsaveSearchTitle").val();
     if (! dat.OQsaveSearchTitle) {
-      alert('enter a name');
+      alert('Enter a name.');
       return true;
     }
-    $.ajax({ url: $f[0].action, type: 'POST', data: dat, dataType: 'html',
-      complete: function(jqXHR) {
-        if (! /report\ saved/.test(jqXHR.responseText))
-          OQnotify("Could not save report.");
-        else {
-          $inp.val(''); 
-          $("h3[data-toolkey=loadreport]").click();
+    dat.alert_mask = 0;
+    if ($("#OQalertenabled").prop("checked")) {
+      dat.alert_mask = 0; $("input[name=OQalert_mask]:checked").each(function(){ dat.alert_mask |= parseInt(this.value,10); });
+      dat.alert_interval_min = parseInt($("#OQalert_interval_min").val(),10);
+
+      if (dat.alert_mask==0) {
+        alert('Specify when to send the alert.');
+        return true;
+      }
+      if (!(dat.alert_interval_min >= 30)) {
+        alert('Enter a "Check Every" minute hour value greater or equal to 30');
+        return true;
+      }
+
+      dat.alert_dow = '';
+      $(".OQalert_dow:checked").each(function(){ dat.alert_dow += this.value; });
+      if (dat.alert_dow == '') {
+        alert('Select at least one "On Days".');
+        return true;
+      }
+
+      dat.alert_start_hour = parseHour($("#OQalert_start_hour").val());
+      if (! dat.alert_start_hour) {
+        alert('Enter a "From" hour between 0 and 23.');
+        return true;
+      }
+
+      dat.alert_end_hour = parseHour($("#OQalert_end_hour").val());
+      if (! dat.alert_end_hour) {
+        alert('Enter a "To" hour between 0 and 23.');
+        return true;
+      }
+
+      if (dat.alert_start_hour > dat.alert_end_hour) {
+        alert('"From" hour must be less than "To" hour.');
+        return true;
+      }
+    }
+    $.ajax({ url: $f[0].action, type: 'POST', data: dat, dataType: 'json',
+      error: function(){
+        OQnotify("Could not save report.");
+      },
+      success: function(x) {
+        if (x.id) {
+          $f[0].OQss.value=x.id;    
+          $('.OQToolsCancelBut').click();
           OQnotify("report saved");
         }
+        else {
+          OQnotify("Could not save report. " + x.msg);
+        }
       }
     });
     return true;
   });
+  $(document).delegate('#OQalertenabled', 'click', function(e) {
+    if (this.checked) {
+      $("#OQSaveReportEmailAlertOpts").addClass('opened');
+    } else {
+      $("#OQSaveReportEmailAlertOpts").removeClass('opened');
+    }
+  });
 
   $(document).delegate('.OQEmailMergePreviewBut, .OQEmailMergeSendEmailBut', 'click', function(e) {
     var $f = $('.OQform');
@@ -267,7 +323,7 @@ if (! window._OQAjaxQueryLoaded)
   $(document).delegate('.OQRemoveAutoActionBut', 'click', function(e) {
     var $f = $('.OQform');
     var $elem = $(this).closest(".AutoActionSummaryElem");
-    var dat = {};
+    var dat = buildParamMap($f);
     dat.module = 'InteractiveQuery2Tools';
     dat.tool = 'autoaction';
     dat.OQRemoveAutoAction = $(this).attr('data-id');
@@ -279,7 +335,7 @@ if (! window._OQAjaxQueryLoaded)
 
   $(document).delegate('.OQEmailMergeDeleteAutoActionBut', 'click', function(e) {
     var $f = $('.OQform');
-    var dat = {};
+    var dat = buildParamMap($f);
     dat.module = 'InteractiveQuery2Tools';
     dat.tool = 'emailmerge';
     dat.act = 'deleteautoaction';
@@ -567,7 +623,9 @@ if (! window._OQAjaxQueryLoaded)
 
   $(document).delegate('.OQPager', 'change', function(e) {
     e.preventDefault();
-    refreshDataGrid($(this).closest('form'));
+    var $f = $(this).closest('form');
+    refreshDataGrid($f);
+    $f[0].scrollIntoView();
     return true;
   });
   $(document).delegate('.OQNextBut', 'click', function(e) {
@@ -576,6 +634,7 @@ if (! window._OQAjaxQueryLoaded)
     var n = parseInt($f[0].page.value,10);
     $f[0].page.value = n + 1;
     refreshDataGrid($f);
+    $f[0].scrollIntoView();
     return true;
   });
   $(document).delegate('.OQPrevBut', 'click', function(e) {
@@ -584,6 +643,7 @@ if (! window._OQAjaxQueryLoaded)
     var n = parseInt($f[0].page.value,10);
     $f[0].page.value = n - 1;
     refreshDataGrid($f);
+    $f[0].scrollIntoView();
     return true;
   });
 
@@ -803,6 +863,7 @@ if (! window._OQAjaxQueryLoaded)
   window.OQrefresh = function(updated_uid) {
     var $f = $('form.OQform').eq(0);
     var onSelFun = $f[0].on_select.value;
+    var isClosed = false;
     if (updated_uid && onSelFun) {
       try {
         var wo = window.opener2 || window.opener;
@@ -810,8 +871,10 @@ if (! window._OQAjaxQueryLoaded)
         wo.focus();
         var wc = window.close2 || window.close;
         wc();
+        isClosed = true;
       } catch(e) {}
-    } else {
+    }
+    if (! isClosed) {
       var dat = buildParamMap($f);
       var $ajax = refreshDataGrid($f,dat);
       if (updated_uid) $ajax.done(function(){
