@@ -53,14 +53,21 @@ sub on_init {
         uri => $$o{schema}{URI},
         oq_title => $$o{schema}{title},
         user_title => $$o{q}->param('OQsaveSearchTitle'),
-        params => $params,
-        alert_mask => $$o{q}->param('alert_mask') || 0
+        params => $params
       );
+
+      # is saved search alerts enabled
+      if ($$o{schema}{savedSearchAlerts}) {
+        $rec{alert_mask} = $$o{q}->param('alert_mask') || 0;
+      }
+
+      # if user enabled search search alerts
       if ($rec{alert_mask}) {
         $rec{alert_interval_min} = $$o{q}->param('alert_interval_min');
         $rec{alert_dow} = $$o{q}->param('alert_dow');
         $rec{alert_start_hour} = $$o{q}->param('alert_start_hour');
         $rec{alert_end_hour} = $$o{q}->param('alert_end_hour');
+        $rec{alert_last_dt} = [get_sysdate_sql($$o{dbh})];
   
         # get starting alert_uids
         my @uids;
@@ -76,7 +83,6 @@ sub on_init {
         }
         die "MAX_ROWS_EXCEEDED - your report contains too many rows to send alerts via email. Reduce the total row count of your report by adding additional filters." if scalar(@uids) > $MAX_ROWS;
         $rec{alert_uids} = join('~', @uids);
-        $rec{alert_uids} = undef if $rec{alert_uids} eq '';
       }
   
       # save saved search to db
@@ -87,8 +93,14 @@ sub on_init {
         if ($is_update) {
           my (@cols,@binds);
           while (my ($col,$val) = each %rec) {
-            push @cols, "$col=?";
-            push @binds, $val;
+            if (ref($val) eq 'ARRAY') {
+              my ($sql,@rest) = @$val;
+              push @cols, "$col=$sql";
+              push @binds, map { $_ eq '' ? undef : $_ } @rest;
+            } else {
+              push @cols, "$col=?";
+              push @binds, ($val eq '') ? undef : $val;
+            }
           }
           push @binds, $id;
           $$o{dbh}->do("UPDATE oq_saved_search SET ".join(',', @cols)." WHERE id=?", undef, @binds);
@@ -100,8 +112,14 @@ sub on_init {
         my (@cols,@vals,@binds);
         while (my ($col,$val) = each %rec) {
           push @cols, $col;
-          push @vals, '?';
-          push @binds, $val;
+          if (ref($val) eq 'ARRAY') {
+            my ($sql,@rest) = @$val;
+            push @vals, $sql;
+            push @binds, map { $_ eq '' ? undef : $_ } @rest;
+          } else {
+            push @vals, '?';
+            push @binds, ($val eq '') ? undef : $val;
+          }
         }
         $$o{dbh}->do("INSERT INTO oq_saved_search (".join(',',@cols).") VALUES (".join(',',@vals).")", undef, @binds);
         $rec{id} ||= $$o{dbh}->last_insert_id("","","","");
@@ -296,8 +314,10 @@ sub custom_output_handler {
       $buf .= " class=ftv" if $$current_saved_search{uids}{$$rec{U_ID}}==3;
       $buf .= "><td>";
       if ($link) {
-        $link = $$current_saved_search{opts}{base_url}.'/'.$link
-          if $link !~ /^https?\:\/\//i;
+        if ($link !~ /^https?\:\/\//i) {
+          $link .= '/'.$link unless $link =~ /^\//;
+          $link = $$current_saved_search{opts}{base_url}.$link;
+        }
         $buf .= "<a href='".escapeHTML($link)."'>open</a>";
       }
       $buf .= "</td>";
@@ -341,6 +361,24 @@ sub sendmail_handler {
   return Mail::Sendmail::sendmail(%email);
 }
 
+sub get_sysdate_sql {
+  my ($dbh) = @_;
+  my $now;
+  if ($$dbh{Driver}{Name} eq 'Oracle') {
+    $now = 'SYSDATE';
+  } elsif ($$dbh{Driver}{Name} eq 'SQLite') {
+    $now = 'DATETIME()';
+  } elsif ($$dbh{Driver}{Name} eq 'mysql') {
+    $now = 'NOW()';
+  } elsif ($$dbh{Driver}{Name} eq 'Pg' || $$dbh{Driver}{Name} eq 'Microsoft SQL Server') {
+    $now = 'CURRENT_TIMESTAMP';
+  } else {
+    die "Driver: $$dbh{Driver}{Name} not yet supported. Please add support for this database";
+  }
+  return $now;
+}
+
+
 sub execute_saved_search_alerts {
   my %opts = @_;
   my $sendmail_handler = $opts{sendmail_handler} ||= \&sendmail_handler;
@@ -385,6 +423,7 @@ sub execute_saved_search_alerts {
 SELECT *
 FROM oq_saved_search
 WHERE alert_dow LIKE ?
+AND alert_mask > 0
 AND ? BETWEEN alert_start_hour AND alert_end_hour";
 
     # only select if interval has been exceeded
@@ -483,7 +522,14 @@ AND ? BETWEEN alert_start_hour AND alert_end_hour";
           from => $$rec{email_from} || $opts{email_from},
           'Reply-To' => $$rec{'email_Reply-To'} || $opts{'email_Reply-To'},
           subject => "Problem with email alert: $$rec{OQ_TITLE}",
-          body => "Your saved search alert encountered the following error:\n\n$$rec{err_msg}\n\nPlease contact your administrator if you are unable to fix the problem."
+          body => "Your saved search alert encountered the following error:
+
+$$rec{err_msg}
+
+load report:
+".$opts{base_url}.$$rec{URI}.'?OQLoadSavedSearch='.$$rec{ID}.$$rec{state_param_args}."
+
+Please contact your administrator if you are unable to fix the problem."
         );
         $sendmail_handler->(%email) or die "could not send email to: $$rec{email_to}";
       }
@@ -574,7 +620,7 @@ $$rec{buf}
 <span class='ftv ib'>added: $total_new</span>
 <span class=ib>removed: $total_deleted</span>
 <p>
-<a href='".escapeHTML("$ENV{REQUEST_URI}?OQLoadSavedSearch=$$rec{ID}".$$rec{state_param_args})."'>load report</a>
+<a href='".escapeHTML($opts{base_url}.$$rec{URI}.'?OQLoadSavedSearch='.$$rec{ID}.$$rec{state_param_args})."'>load report</a>
 </div>
 </body>
 </html>";
@@ -589,18 +635,7 @@ $$rec{buf}
     $update_uids = undef if $update_uids eq '';
     $$rec{err_msg} = undef if $$rec{err_msg} eq '';
     my @binds = ($$rec{err_msg});
-    my $now;
-    if ($$dbh{Driver}{Name} eq 'Oracle') {
-      $now = 'SYSDATE';
-    } elsif ($$dbh{Driver}{Name} eq 'SQLite') {
-      $now = 'DATETIME()';
-    } elsif ($$dbh{Driver}{Name} eq 'mysql') {
-      $now = 'NOW()';
-    } elsif ($$dbh{Driver}{Name} eq 'Pg' || $$dbh{Driver}{Name} eq 'Microsoft SQL Server') {
-      $now = 'CURRENT_TIMESTAMP';
-    } else {
-      die "Driver: $$dbh{Driver}{Name} not yet supported. Please add support for this database";
-    }
+    my $now = get_sysdate_sql($dbh);
 
     my $sql = "UPDATE oq_saved_search SET alert_last_dt=$now, alert_err=?";
     if ($update_uids ne $$rec{ALERT_UIDS}) {
